@@ -127,5 +127,10 @@ exports["Africa/Algiers"] = {
 		["1980-04-25T00:00:00+00:00", "01:00:00", "WEST", -60],
 		["1980-10-31T00:59:59+00:00", "01:59:59", "WEST", -60],
 		["1980-10-31T01:00:00+00:00", "01:00:00", "WET", 0]
+	]),
+
+	"1981" : helpers.makeTestYear("Africa/Algiers", [
+		["1981-04-30T23:59:59+00:00", "23:59:59", "WET", 0],
+		["1981-05-01T00:00:00+00:00", "01:00:00", "CET", -60]
 	])
 };
\ No newline at end of file
