@@ -438,6 +438,8 @@ exports["Africa/Cairo"] = {
 		["2014-06-26T20:59:59+00:00", "23:59:59", "EEST", -180],
 		["2014-06-26T21:00:00+00:00", "23:00:00", "EET", -120],
 		["2014-07-31T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2014-07-31T22:00:00+00:00", "01:00:00", "EEST", -180]
+		["2014-07-31T22:00:00+00:00", "01:00:00", "EEST", -180],
+		["2014-09-25T20:59:59+00:00", "23:59:59", "EEST", -180],
+		["2014-09-25T21:00:00+00:00", "23:00:00", "EET", -120]
 	])
 };
\ No newline at end of file
