@@ -8,6 +8,11 @@ exports["Africa/Tripoli"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Africa/Tripoli", { abbr: true, expect: "Africa/Cairo" }),
 
+	"1919" : helpers.makeTestYear("Africa/Tripoli", [
+		["1919-12-31T23:07:15+00:00", "23:59:59", "LMT", -3164 / 60],
+		["1919-12-31T23:07:16+00:00", "00:07:16", "CET", -60]
+	]),
+
 	"1951" : helpers.makeTestYear("Africa/Tripoli", [
 		["1951-10-14T00:59:59+00:00", "01:59:59", "CET", -60],
 		["1951-10-14T01:00:00+00:00", "03:00:00", "CEST", -120],
@@ -119,6 +124,8 @@ exports["Africa/Tripoli"] = {
 
 	"2013" : helpers.makeTestYear("Africa/Tripoli", [
 		["2013-03-28T23:59:59+00:00", "00:59:59", "CET", -60],
-		["2013-03-29T00:00:00+00:00", "02:00:00", "CEST", -120]
+		["2013-03-29T00:00:00+00:00", "02:00:00", "CEST", -120],
+		["2013-10-24T23:59:59+00:00", "01:59:59", "CEST", -120],
+		["2013-10-25T00:00:00+00:00", "02:00:00", "EET", -120]
 	])
 };
\ No newline at end of file
