@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["America/Asuncion"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("America/Asuncion", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("America/Asuncion", { abbr: true }),
+
 	"1931" : helpers.makeTestYear("America/Asuncion", [
 		["1931-10-10T03:50:39+00:00", "23:59:59", "AMT", 13840 / 60],
 		["1931-10-10T03:50:40+00:00", "23:50:40", "-04", 240]
