@@ -204,6 +204,8 @@ exports["America/Dawson_Creek"] = {
 
 	"1972" : helpers.makeTestYear("America/Dawson_Creek", [
 		["1972-04-30T09:59:59+00:00", "01:59:59", "PST", 480],
-		["1972-04-30T10:00:00+00:00", "03:00:00", "PDT", 420]
+		["1972-04-30T10:00:00+00:00", "03:00:00", "PDT", 420],
+		["1972-08-30T08:59:59+00:00", "01:59:59", "PDT", 420],
+		["1972-08-30T09:00:00+00:00", "02:00:00", "MST", 420]
 	])
 };
\ No newline at end of file
