@@ -74,20 +74,6 @@ exports["America/Edmonton"] = {
 		["1947-09-28T08:00:00+00:00", "01:00:00", "MST", 420]
 	]),
 
-	"1967" : helpers.makeTestYear("America/Edmonton", [
-		["1967-04-30T08:59:59+00:00", "01:59:59", "MST", 420],
-		["1967-04-30T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["1967-10-29T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["1967-10-29T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"1969" : helpers.makeTestYear("America/Edmonton", [
-		["1969-04-27T08:59:59+00:00", "01:59:59", "MST", 420],
-		["1969-04-27T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["1969-10-26T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["1969-10-26T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
 	"1972" : helpers.makeTestYear("America/Edmonton", [
 		["1972-04-30T08:59:59+00:00", "01:59:59", "MST", 420],
 		["1972-04-30T09:00:00+00:00", "03:00:00", "MDT", 360],
