@@ -8,6 +8,11 @@ exports["America/Eirunepe"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("America/Eirunepe", { abbr: true, expect: "America/Lima" }),
 
+	"1914" : helpers.makeTestYear("America/Eirunepe", [
+		["1914-01-01T04:39:27+00:00", "23:59:59", "LMT", 16768 / 60],
+		["1914-01-01T04:39:28+00:00", "23:39:28", "-05", 300]
+	]),
+
 	"1931" : helpers.makeTestYear("America/Eirunepe", [
 		["1931-10-03T15:59:59+00:00", "10:59:59", "-05", 300],
 		["1931-10-03T16:00:00+00:00", "12:00:00", "-04", 240]
@@ -131,5 +136,10 @@ exports["America/Eirunepe"] = {
 	"2008" : helpers.makeTestYear("America/Eirunepe", [
 		["2008-06-24T04:59:59+00:00", "23:59:59", "-05", 300],
 		["2008-06-24T05:00:00+00:00", "01:00:00", "-04", 240]
+	]),
+
+	"2013" : helpers.makeTestYear("America/Eirunepe", [
+		["2013-11-10T03:59:59+00:00", "23:59:59", "-04", 240],
+		["2013-11-10T04:00:00+00:00", "23:00:00", "-05", 300]
 	])
 };
\ No newline at end of file
