@@ -8,6 +8,11 @@ exports["America/Guatemala"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("America/Guatemala", { abbr: true, expect: "America/Managua" }),
 
+	"1918" : helpers.makeTestYear("America/Guatemala", [
+		["1918-10-05T06:02:03+00:00", "23:59:59", "LMT", 21724 / 60],
+		["1918-10-05T06:02:04+00:00", "00:02:04", "CST", 360]
+	]),
+
 	"1973" : helpers.makeTestYear("America/Guatemala", [
 		["1973-11-25T05:59:59+00:00", "23:59:59", "CST", 360],
 		["1973-11-25T06:00:00+00:00", "01:00:00", "CDT", 300]
@@ -34,6 +39,8 @@ exports["America/Guatemala"] = {
 
 	"2006" : helpers.makeTestYear("America/Guatemala", [
 		["2006-04-30T05:59:59+00:00", "23:59:59", "CST", 360],
-		["2006-04-30T06:00:00+00:00", "01:00:00", "CDT", 300]
+		["2006-04-30T06:00:00+00:00", "01:00:00", "CDT", 300],
+		["2006-10-01T04:59:59+00:00", "23:59:59", "CDT", 300],
+		["2006-10-01T05:00:00+00:00", "23:00:00", "CST", 360]
 	])
 };
\ No newline at end of file
