@@ -16,5 +16,10 @@ exports["America/Guayaquil"] = {
 	"1992" : helpers.makeTestYear("America/Guayaquil", [
 		["1992-11-28T04:59:59+00:00", "23:59:59", "-05", 300],
 		["1992-11-28T05:00:00+00:00", "01:00:00", "-04", 240]
+	]),
+
+	"1993" : helpers.makeTestYear("America/Guayaquil", [
+		["1993-02-05T03:59:59+00:00", "23:59:59", "-04", 240],
+		["1993-02-05T04:00:00+00:00", "23:00:00", "-05", 300]
 	])
 };
\ No newline at end of file
