@@ -8,9 +8,301 @@ exports["America/Nassau"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("America/Nassau", { abbr: true, expect: "America/New_York" }),
 
-	"1912" : helpers.makeTestYear("America/Nassau", [
-		["1912-03-02T05:09:29+00:00", "23:59:59", "LMT", 18570 / 60],
-		["1912-03-02T05:09:30+00:00", "00:09:30", "EST", 300]
+	"1918" : helpers.makeTestYear("America/Nassau", [
+		["1918-04-14T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1918-04-14T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1918-10-27T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1918-10-27T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1919" : helpers.makeTestYear("America/Nassau", [
+		["1919-03-31T04:29:59+00:00", "23:29:59", "EST", 300],
+		["1919-03-31T04:30:00+00:00", "00:30:00", "EDT", 240],
+		["1919-10-26T03:59:59+00:00", "23:59:59", "EDT", 240],
+		["1919-10-26T04:00:00+00:00", "23:00:00", "EST", 300]
+	]),
+
+	"1920" : helpers.makeTestYear("America/Nassau", [
+		["1920-05-02T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1920-05-02T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1920-09-26T03:59:59+00:00", "23:59:59", "EDT", 240],
+		["1920-09-26T04:00:00+00:00", "23:00:00", "EST", 300]
+	]),
+
+	"1921" : helpers.makeTestYear("America/Nassau", [
+		["1921-05-15T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1921-05-15T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1921-09-15T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1921-09-15T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1922" : helpers.makeTestYear("America/Nassau", [
+		["1922-05-14T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1922-05-14T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1922-09-17T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1922-09-17T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1923" : helpers.makeTestYear("America/Nassau", [
+		["1923-05-13T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1923-05-13T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1923-09-16T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1923-09-16T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1924" : helpers.makeTestYear("America/Nassau", [
+		["1924-05-04T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1924-05-04T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1924-09-21T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1924-09-21T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1925" : helpers.makeTestYear("America/Nassau", [
+		["1925-05-03T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1925-05-03T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1925-09-20T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1925-09-20T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1926" : helpers.makeTestYear("America/Nassau", [
+		["1926-05-02T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1926-05-02T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1926-09-19T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1926-09-19T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1927" : helpers.makeTestYear("America/Nassau", [
+		["1927-05-01T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1927-05-01T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1927-09-25T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1927-09-25T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1928" : helpers.makeTestYear("America/Nassau", [
+		["1928-04-29T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1928-04-29T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1928-09-30T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1928-09-30T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1929" : helpers.makeTestYear("America/Nassau", [
+		["1929-04-28T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1929-04-28T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1929-09-29T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1929-09-29T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1930" : helpers.makeTestYear("America/Nassau", [
+		["1930-04-27T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1930-04-27T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1930-09-28T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1930-09-28T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1931" : helpers.makeTestYear("America/Nassau", [
+		["1931-04-26T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1931-04-26T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1931-09-27T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1931-09-27T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1932" : helpers.makeTestYear("America/Nassau", [
+		["1932-05-01T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1932-05-01T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1932-09-25T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1932-09-25T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1933" : helpers.makeTestYear("America/Nassau", [
+		["1933-04-30T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1933-04-30T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1933-10-01T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1933-10-01T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1934" : helpers.makeTestYear("America/Nassau", [
+		["1934-04-29T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1934-04-29T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1934-09-30T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1934-09-30T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1935" : helpers.makeTestYear("America/Nassau", [
+		["1935-04-28T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1935-04-28T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1935-09-29T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1935-09-29T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1936" : helpers.makeTestYear("America/Nassau", [
+		["1936-04-26T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1936-04-26T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1936-09-27T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1936-09-27T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1937" : helpers.makeTestYear("America/Nassau", [
+		["1937-04-25T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1937-04-25T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1937-09-26T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1937-09-26T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1938" : helpers.makeTestYear("America/Nassau", [
+		["1938-04-24T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1938-04-24T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1938-09-25T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1938-09-25T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1939" : helpers.makeTestYear("America/Nassau", [
+		["1939-04-30T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1939-04-30T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1939-09-24T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1939-09-24T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1940" : helpers.makeTestYear("America/Nassau", [
+		["1940-04-28T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1940-04-28T07:00:00+00:00", "03:00:00", "EDT", 240]
+	]),
+
+	"1942" : helpers.makeTestYear("America/Nassau", [
+		["1942-02-09T06:59:59+00:00", "02:59:59", "EDT", 240],
+		["1942-02-09T07:00:00+00:00", "03:00:00", "EWT", 240]
+	]),
+
+	"1945" : helpers.makeTestYear("America/Nassau", [
+		["1945-08-14T22:59:59+00:00", "18:59:59", "EWT", 240],
+		["1945-08-14T23:00:00+00:00", "19:00:00", "EPT", 240],
+		["1945-09-30T05:59:59+00:00", "01:59:59", "EPT", 240],
+		["1945-09-30T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1946" : helpers.makeTestYear("America/Nassau", [
+		["1946-04-28T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1946-04-28T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1946-09-29T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1946-09-29T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1947" : helpers.makeTestYear("America/Nassau", [
+		["1947-04-27T04:59:59+00:00", "23:59:59", "EST", 300],
+		["1947-04-27T05:00:00+00:00", "01:00:00", "EDT", 240],
+		["1947-09-28T03:59:59+00:00", "23:59:59", "EDT", 240],
+		["1947-09-28T04:00:00+00:00", "23:00:00", "EST", 300]
+	]),
+
+	"1948" : helpers.makeTestYear("America/Nassau", [
+		["1948-04-25T04:59:59+00:00", "23:59:59", "EST", 300],
+		["1948-04-25T05:00:00+00:00", "01:00:00", "EDT", 240],
+		["1948-09-26T03:59:59+00:00", "23:59:59", "EDT", 240],
+		["1948-09-26T04:00:00+00:00", "23:00:00", "EST", 300]
+	]),
+
+	"1949" : helpers.makeTestYear("America/Nassau", [
+		["1949-04-24T04:59:59+00:00", "23:59:59", "EST", 300],
+		["1949-04-24T05:00:00+00:00", "01:00:00", "EDT", 240],
+		["1949-11-27T03:59:59+00:00", "23:59:59", "EDT", 240],
+		["1949-11-27T04:00:00+00:00", "23:00:00", "EST", 300]
+	]),
+
+	"1950" : helpers.makeTestYear("America/Nassau", [
+		["1950-04-30T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1950-04-30T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1950-11-26T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1950-11-26T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1951" : helpers.makeTestYear("America/Nassau", [
+		["1951-04-29T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1951-04-29T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1951-09-30T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1951-09-30T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1952" : helpers.makeTestYear("America/Nassau", [
+		["1952-04-27T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1952-04-27T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1952-09-28T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1952-09-28T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1953" : helpers.makeTestYear("America/Nassau", [
+		["1953-04-26T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1953-04-26T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1953-09-27T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1953-09-27T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1954" : helpers.makeTestYear("America/Nassau", [
+		["1954-04-25T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1954-04-25T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1954-09-26T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1954-09-26T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1955" : helpers.makeTestYear("America/Nassau", [
+		["1955-04-24T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1955-04-24T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1955-09-25T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1955-09-25T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1956" : helpers.makeTestYear("America/Nassau", [
+		["1956-04-29T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1956-04-29T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1956-09-30T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1956-09-30T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1957" : helpers.makeTestYear("America/Nassau", [
+		["1957-04-28T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1957-04-28T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1957-10-27T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1957-10-27T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1958" : helpers.makeTestYear("America/Nassau", [
+		["1958-04-27T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1958-04-27T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1958-10-26T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1958-10-26T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1959" : helpers.makeTestYear("America/Nassau", [
+		["1959-04-26T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1959-04-26T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1959-10-25T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1959-10-25T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1960" : helpers.makeTestYear("America/Nassau", [
+		["1960-04-24T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1960-04-24T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1960-10-30T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1960-10-30T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1961" : helpers.makeTestYear("America/Nassau", [
+		["1961-04-30T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1961-04-30T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1961-10-29T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1961-10-29T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1962" : helpers.makeTestYear("America/Nassau", [
+		["1962-04-29T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1962-04-29T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1962-10-28T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1962-10-28T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1963" : helpers.makeTestYear("America/Nassau", [
+		["1963-04-28T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1963-04-28T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1963-10-27T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1963-10-27T06:00:00+00:00", "01:00:00", "EST", 300]
 	]),
 
 	"1964" : helpers.makeTestYear("America/Nassau", [
