@@ -4,9 +4,9 @@ var helpers = require("../../helpers/helpers");
 
 exports["America/Port-au-Prince"] = {
 
-	"guess:by:offset" : helpers.makeTestGuess("America/Port-au-Prince", { offset: true }),
+	"guess:by:offset" : helpers.makeTestGuess("America/Port-au-Prince", { offset: true, expect: "America/New_York" }),
 
-	"guess:by:abbr" : helpers.makeTestGuess("America/Port-au-Prince", { abbr: true }),
+	"guess:by:abbr" : helpers.makeTestGuess("America/Port-au-Prince", { abbr: true, expect: "America/New_York" }),
 
 	"1917" : helpers.makeTestYear("America/Port-au-Prince", [
 		["1917-01-24T16:48:59+00:00", "11:59:59", "PPMT", 289],
