@@ -337,134 +337,6 @@ exports["America/Sao_Paulo"] = {
 
 	"2019" : helpers.makeTestYear("America/Sao_Paulo", [
 		["2019-02-17T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2019-02-17T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2019-11-03T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2019-11-03T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2020" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2020-02-16T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2020-02-16T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2020-11-01T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2020-11-01T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2021" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2021-02-21T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2021-02-21T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2021-11-07T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2021-11-07T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2022" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2022-02-20T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2022-02-20T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2022-11-06T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2022-11-06T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2023" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2023-02-26T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2023-02-26T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2023-11-05T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2023-11-05T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2024" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2024-02-18T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2024-02-18T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2024-11-03T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2024-11-03T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2025" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2025-02-16T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2025-02-16T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2025-11-02T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2025-11-02T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2026" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2026-02-22T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2026-02-22T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2026-11-01T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2026-11-01T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2027" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2027-02-21T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2027-02-21T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2027-11-07T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2027-11-07T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2028" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2028-02-20T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2028-02-20T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2028-11-05T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2028-11-05T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2029" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2029-02-18T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2029-02-18T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2029-11-04T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2029-11-04T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2030" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2030-02-17T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2030-02-17T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2030-11-03T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2030-11-03T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2031" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2031-02-16T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2031-02-16T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2031-11-02T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2031-11-02T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2032" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2032-02-15T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2032-02-15T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2032-11-07T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2032-11-07T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2033" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2033-02-20T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2033-02-20T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2033-11-06T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2033-11-06T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2034" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2034-02-26T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2034-02-26T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2034-11-05T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2034-11-05T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2035" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2035-02-18T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2035-02-18T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2035-11-04T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2035-11-04T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2036" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2036-02-17T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2036-02-17T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2036-11-02T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2036-11-02T03:00:00+00:00", "01:00:00", "-02", 120]
-	]),
-
-	"2037" : helpers.makeTestYear("America/Sao_Paulo", [
-		["2037-02-22T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2037-02-22T02:00:00+00:00", "23:00:00", "-03", 180],
-		["2037-11-01T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2037-11-01T03:00:00+00:00", "01:00:00", "-02", 120]
+		["2019-02-17T02:00:00+00:00", "23:00:00", "-03", 180]
 	])
 };
\ No newline at end of file
