@@ -8,8 +8,8 @@ exports["Antarctica/Syowa"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Antarctica/Syowa", { abbr: true, expect: "Europe/Moscow" }),
 
-	"1957" : helpers.makeTestYear("Antarctica/Syowa", [
-		["1957-01-28T23:59:59+00:00", "23:59:59", "-00", 0],
-		["1957-01-29T00:00:00+00:00", "03:00:00", "+03", -180]
+	"1947" : helpers.makeTestYear("Antarctica/Syowa", [
+		["1947-03-13T20:53:07+00:00", "23:59:59", "LMT", -11212 / 60],
+		["1947-03-13T20:53:08+00:00", "23:53:08", "+03", -180]
 	])
 };
\ No newline at end of file
