@@ -8,6 +8,11 @@ exports["Asia/Anadyr"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Anadyr", { abbr: true, expect: "Asia/Kamchatka" }),
 
+	"1924" : helpers.makeTestYear("Asia/Anadyr", [
+		["1924-05-01T12:10:03+00:00", "23:59:59", "LMT", -42596 / 60],
+		["1924-05-01T12:10:04+00:00", "00:10:04", "+12", -720]
+	]),
+
 	"1930" : helpers.makeTestYear("Asia/Anadyr", [
 		["1930-06-20T11:59:59+00:00", "23:59:59", "+12", -720],
 		["1930-06-20T12:00:00+00:00", "01:00:00", "+13", -780]
@@ -223,5 +228,10 @@ exports["Asia/Anadyr"] = {
 		["2010-03-27T14:00:00+00:00", "02:00:00", "+12", -720],
 		["2010-10-30T14:59:59+00:00", "02:59:59", "+12", -720],
 		["2010-10-30T15:00:00+00:00", "02:00:00", "+11", -660]
+	]),
+
+	"2011" : helpers.makeTestYear("Asia/Anadyr", [
+		["2011-03-26T14:59:59+00:00", "01:59:59", "+11", -660],
+		["2011-03-26T15:00:00+00:00", "03:00:00", "+12", -720]
 	])
 };
\ No newline at end of file
