@@ -8,6 +8,11 @@ exports["Asia/Baku"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Baku", { abbr: true, expect: "Asia/Dubai" }),
 
+	"1924" : helpers.makeTestYear("Asia/Baku", [
+		["1924-05-01T20:40:35+00:00", "23:59:59", "LMT", -11964 / 60],
+		["1924-05-01T20:40:36+00:00", "23:40:36", "+03", -180]
+	]),
+
 	"1957" : helpers.makeTestYear("Asia/Baku", [
 		["1957-02-28T20:59:59+00:00", "23:59:59", "+03", -180],
 		["1957-02-28T21:00:00+00:00", "01:00:00", "+04", -240]
@@ -232,6 +237,8 @@ exports["Asia/Baku"] = {
 
 	"2015" : helpers.makeTestYear("Asia/Baku", [
 		["2015-03-28T23:59:59+00:00", "03:59:59", "+04", -240],
-		["2015-03-29T00:00:00+00:00", "05:00:00", "+05", -300]
+		["2015-03-29T00:00:00+00:00", "05:00:00", "+05", -300],
+		["2015-10-24T23:59:59+00:00", "04:59:59", "+05", -300],
+		["2015-10-25T00:00:00+00:00", "04:00:00", "+04", -240]
 	])
 };
\ No newline at end of file
