@@ -8,6 +8,11 @@ exports["Asia/Bishkek"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Bishkek", { abbr: true, expect: "Asia/Dhaka" }),
 
+	"1924" : helpers.makeTestYear("Asia/Bishkek", [
+		["1924-05-01T19:01:35+00:00", "23:59:59", "LMT", -17904 / 60],
+		["1924-05-01T19:01:36+00:00", "00:01:36", "+05", -300]
+	]),
+
 	"1930" : helpers.makeTestYear("Asia/Bishkek", [
 		["1930-06-20T18:59:59+00:00", "23:59:59", "+05", -300],
 		["1930-06-20T19:00:00+00:00", "01:00:00", "+06", -360]
@@ -183,6 +188,8 @@ exports["Asia/Bishkek"] = {
 
 	"2005" : helpers.makeTestYear("Asia/Bishkek", [
 		["2005-03-26T21:29:59+00:00", "02:29:59", "+05", -300],
-		["2005-03-26T21:30:00+00:00", "03:30:00", "+06", -360]
+		["2005-03-26T21:30:00+00:00", "03:30:00", "+06", -360],
+		["2005-08-11T17:59:59+00:00", "23:59:59", "+06", -360],
+		["2005-08-11T18:00:00+00:00", "00:00:00", "+06", -360]
 	])
 };
\ No newline at end of file
