@@ -30,5 +30,10 @@ exports["Asia/Colombo"] = {
 		["1996-05-24T18:30:00+00:00", "01:00:00", "+0630", -390],
 		["1996-10-25T17:59:59+00:00", "00:29:59", "+0630", -390],
 		["1996-10-25T18:00:00+00:00", "00:00:00", "+06", -360]
+	]),
+
+	"2006" : helpers.makeTestYear("Asia/Colombo", [
+		["2006-04-14T18:29:59+00:00", "00:29:59", "+06", -360],
+		["2006-04-14T18:30:00+00:00", "00:00:00", "+0530", -330]
 	])
 };
\ No newline at end of file
