@@ -8,6 +8,11 @@ exports["Asia/Oral"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Oral", { abbr: true, expect: "Asia/Karachi" }),
 
+	"1924" : helpers.makeTestYear("Asia/Oral", [
+		["1924-05-01T20:34:35+00:00", "23:59:59", "LMT", -12324 / 60],
+		["1924-05-01T20:34:36+00:00", "23:34:36", "+03", -180]
+	]),
+
 	"1930" : helpers.makeTestYear("Asia/Oral", [
 		["1930-06-20T20:59:59+00:00", "23:59:59", "+03", -180],
 		["1930-06-20T21:00:00+00:00", "02:00:00", "+05", -300]
@@ -178,6 +183,8 @@ exports["Asia/Oral"] = {
 
 	"2004" : helpers.makeTestYear("Asia/Oral", [
 		["2004-03-27T21:59:59+00:00", "01:59:59", "+04", -240],
-		["2004-03-27T22:00:00+00:00", "03:00:00", "+05", -300]
+		["2004-03-27T22:00:00+00:00", "03:00:00", "+05", -300],
+		["2004-10-30T21:59:59+00:00", "02:59:59", "+05", -300],
+		["2004-10-30T22:00:00+00:00", "03:00:00", "+05", -300]
 	])
 };
\ No newline at end of file
