@@ -4,9 +4,9 @@ var helpers = require("../../helpers/helpers");
 
 exports["Asia/Pyongyang"] = {
 
-	"guess:by:offset" : helpers.makeTestGuess("Asia/Pyongyang", { offset: true }),
+	"guess:by:offset" : helpers.makeTestGuess("Asia/Pyongyang", { offset: true, expect: "Asia/Tokyo" }),
 
-	"guess:by:abbr" : helpers.makeTestGuess("Asia/Pyongyang", { abbr: true }),
+	"guess:by:abbr" : helpers.makeTestGuess("Asia/Pyongyang", { abbr: true, expect: "Asia/Seoul" }),
 
 	"1908" : helpers.makeTestYear("Asia/Pyongyang", [
 		["1908-03-31T15:36:59+00:00", "23:59:59", "LMT", -503],
