@@ -8,6 +8,11 @@ exports["Asia/Saigon"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Saigon", { abbr: true, expect: "Asia/Jakarta" }),
 
+	"1906" : helpers.makeTestYear("Asia/Saigon", [
+		["1906-06-30T16:53:19+00:00", "23:59:59", "LMT", -25600 / 60],
+		["1906-06-30T16:53:20+00:00", "23:59:50", "PLMT", -25590 / 60]
+	]),
+
 	"1911" : helpers.makeTestYear("Asia/Saigon", [
 		["1911-04-30T16:53:29+00:00", "23:59:59", "PLMT", -25590 / 60],
 		["1911-04-30T16:53:30+00:00", "23:53:30", "+07", -420]
@@ -38,5 +43,10 @@ exports["Asia/Saigon"] = {
 	"1959" : helpers.makeTestYear("Asia/Saigon", [
 		["1959-12-31T15:59:59+00:00", "22:59:59", "+07", -420],
 		["1959-12-31T16:00:00+00:00", "00:00:00", "+08", -480]
+	]),
+
+	"1975" : helpers.makeTestYear("Asia/Saigon", [
+		["1975-06-12T15:59:59+00:00", "23:59:59", "+08", -480],
+		["1975-06-12T16:00:00+00:00", "23:00:00", "+07", -420]
 	])
 };
\ No newline at end of file
