@@ -146,6 +146,8 @@ exports["Asia/Taipei"] = {
 
 	"1979" : helpers.makeTestYear("Asia/Taipei", [
 		["1979-06-30T15:59:59+00:00", "23:59:59", "CST", -480],
-		["1979-06-30T16:00:00+00:00", "01:00:00", "CDT", -540]
+		["1979-06-30T16:00:00+00:00", "01:00:00", "CDT", -540],
+		["1979-09-30T14:59:59+00:00", "23:59:59", "CDT", -540],
+		["1979-09-30T15:00:00+00:00", "23:00:00", "CST", -480]
 	])
 };
\ No newline at end of file
