@@ -8,6 +8,11 @@ exports["Asia/Ust-Nera"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Ust-Nera", { abbr: true, expect: "Australia/Brisbane" }),
 
+	"1919" : helpers.makeTestYear("Asia/Ust-Nera", [
+		["1919-12-14T14:27:05+00:00", "23:59:59", "LMT", -34374 / 60],
+		["1919-12-14T14:27:06+00:00", "22:27:06", "+08", -480]
+	]),
+
 	"1930" : helpers.makeTestYear("Asia/Ust-Nera", [
 		["1930-06-20T15:59:59+00:00", "23:59:59", "+08", -480],
 		["1930-06-20T16:00:00+00:00", "01:00:00", "+09", -540]
@@ -230,5 +235,10 @@ exports["Asia/Ust-Nera"] = {
 		["2011-03-26T15:00:00+00:00", "03:00:00", "+12", -720],
 		["2011-09-12T11:59:59+00:00", "23:59:59", "+12", -720],
 		["2011-09-12T12:00:00+00:00", "23:00:00", "+11", -660]
+	]),
+
+	"2014" : helpers.makeTestYear("Asia/Ust-Nera", [
+		["2014-10-25T14:59:59+00:00", "01:59:59", "+11", -660],
+		["2014-10-25T15:00:00+00:00", "01:00:00", "+10", -600]
 	])
 };
\ No newline at end of file
