@@ -8,5 +8,8 @@ exports["Asia/Vientiane"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Vientiane", { abbr: true, expect: "Asia/Jakarta" }),
 
-
+	"1920" : helpers.makeTestYear("Asia/Vientiane", [
+		["1920-03-31T17:17:55+00:00", "23:59:59", "BMT", -24124 / 60],
+		["1920-03-31T17:17:56+00:00", "00:17:56", "+07", -420]
+	])
 };
\ No newline at end of file
