@@ -16,5 +16,10 @@ exports["Asia/Yangon"] = {
 	"1942" : helpers.makeTestYear("Asia/Yangon", [
 		["1942-04-30T17:29:59+00:00", "23:59:59", "+0630", -390],
 		["1942-04-30T17:30:00+00:00", "02:30:00", "+09", -540]
+	]),
+
+	"1945" : helpers.makeTestYear("Asia/Yangon", [
+		["1945-05-02T14:59:59+00:00", "23:59:59", "+09", -540],
+		["1945-05-02T15:00:00+00:00", "21:30:00", "+0630", -390]
 	])
 };
\ No newline at end of file
