@@ -232,6 +232,13 @@ exports["Atlantic/Azores"] = {
 		["1949-10-02T04:00:00+00:00", "02:00:00", "-02", 120]
 	]),
 
+	"1950" : helpers.makeTestYear("Atlantic/Azores", [
+		["1950-04-02T03:59:59+00:00", "01:59:59", "-02", 120],
+		["1950-04-02T04:00:00+00:00", "03:00:00", "-01", 60],
+		["1950-10-01T03:59:59+00:00", "02:59:59", "-01", 60],
+		["1950-10-01T04:00:00+00:00", "02:00:00", "-02", 120]
+	]),
+
 	"1951" : helpers.makeTestYear("Atlantic/Azores", [
 		["1951-04-01T03:59:59+00:00", "01:59:59", "-02", 120],
 		["1951-04-01T04:00:00+00:00", "03:00:00", "-01", 60],
