@@ -8,11 +8,102 @@ exports["Atlantic/Bermuda"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Atlantic/Bermuda", { abbr: true, expect: "America/Halifax" }),
 
+	"1917" : helpers.makeTestYear("Atlantic/Bermuda", [
+		["1917-04-06T04:19:17+00:00", "23:59:59", "BMT", 15558 / 60],
+		["1917-04-06T04:19:18+00:00", "01:00:00", "BST", 11958 / 60],
+		["1917-10-01T03:19:17+00:00", "23:59:59", "BST", 11958 / 60],
+		["1917-10-01T03:19:18+00:00", "23:00:00", "BMT", 15558 / 60]
+	]),
+
+	"1918" : helpers.makeTestYear("Atlantic/Bermuda", [
+		["1918-04-14T04:19:17+00:00", "23:59:59", "BMT", 15558 / 60],
+		["1918-04-14T04:19:18+00:00", "01:00:00", "BST", 11958 / 60],
+		["1918-09-16T03:19:17+00:00", "23:59:59", "BST", 11958 / 60],
+		["1918-09-16T03:19:18+00:00", "23:00:00", "BMT", 15558 / 60]
+	]),
+
 	"1930" : helpers.makeTestYear("Atlantic/Bermuda", [
-		["1930-01-01T06:19:17+00:00", "01:59:59", "LMT", 15558 / 60],
+		["1930-01-01T06:19:17+00:00", "01:59:59", "BMT", 15558 / 60],
 		["1930-01-01T06:19:18+00:00", "02:19:18", "AST", 240]
 	]),
 
+	"1942" : helpers.makeTestYear("Atlantic/Bermuda", [
+		["1942-01-11T05:59:59+00:00", "01:59:59", "AST", 240],
+		["1942-01-11T06:00:00+00:00", "03:00:00", "ADT", 180],
+		["1942-10-18T04:59:59+00:00", "01:59:59", "ADT", 180],
+		["1942-10-18T05:00:00+00:00", "01:00:00", "AST", 240]
+	]),
+
+	"1943" : helpers.makeTestYear("Atlantic/Bermuda", [
+		["1943-03-21T05:59:59+00:00", "01:59:59", "AST", 240],
+		["1943-03-21T06:00:00+00:00", "03:00:00", "ADT", 180],
+		["1943-10-31T04:59:59+00:00", "01:59:59", "ADT", 180],
+		["1943-10-31T05:00:00+00:00", "01:00:00", "AST", 240]
+	]),
+
+	"1944" : helpers.makeTestYear("Atlantic/Bermuda", [
+		["1944-03-12T05:59:59+00:00", "01:59:59", "AST", 240],
+		["1944-03-12T06:00:00+00:00", "03:00:00", "ADT", 180],
+		["1944-11-05T04:59:59+00:00", "01:59:59", "ADT", 180],
+		["1944-11-05T05:00:00+00:00", "01:00:00", "AST", 240]
+	]),
+
+	"1945" : helpers.makeTestYear("Atlantic/Bermuda", [
+		["1945-03-11T05:59:59+00:00", "01:59:59", "AST", 240],
+		["1945-03-11T06:00:00+00:00", "03:00:00", "ADT", 180],
+		["1945-11-04T04:59:59+00:00", "01:59:59", "ADT", 180],
+		["1945-11-04T05:00:00+00:00", "01:00:00", "AST", 240]
+	]),
+
+	"1947" : helpers.makeTestYear("Atlantic/Bermuda", [
+		["1947-05-18T05:59:59+00:00", "01:59:59", "AST", 240],
+		["1947-05-18T06:00:00+00:00", "03:00:00", "ADT", 180],
+		["1947-09-14T04:59:59+00:00", "01:59:59", "ADT", 180],
+		["1947-09-14T05:00:00+00:00", "01:00:00", "AST", 240]
+	]),
+
+	"1948" : helpers.makeTestYear("Atlantic/Bermuda", [
+		["1948-05-23T05:59:59+00:00", "01:59:59", "AST", 240],
+		["1948-05-23T06:00:00+00:00", "03:00:00", "ADT", 180],
+		["1948-09-05T04:59:59+00:00", "01:59:59", "ADT", 180],
+		["1948-09-05T05:00:00+00:00", "01:00:00", "AST", 240]
+	]),
+
+	"1949" : helpers.makeTestYear("Atlantic/Bermuda", [
+		["1949-05-22T05:59:59+00:00", "01:59:59", "AST", 240],
+		["1949-05-22T06:00:00+00:00", "03:00:00", "ADT", 180],
+		["1949-09-04T04:59:59+00:00", "01:59:59", "ADT", 180],
+		["1949-09-04T05:00:00+00:00", "01:00:00", "AST", 240]
+	]),
+
+	"1950" : helpers.makeTestYear("Atlantic/Bermuda", [
+		["1950-05-28T05:59:59+00:00", "01:59:59", "AST", 240],
+		["1950-05-28T06:00:00+00:00", "03:00:00", "ADT", 180],
+		["1950-09-03T04:59:59+00:00", "01:59:59", "ADT", 180],
+		["1950-09-03T05:00:00+00:00", "01:00:00", "AST", 240]
+	]),
+
+	"1951" : helpers.makeTestYear("Atlantic/Bermuda", [
+		["1951-05-27T05:59:59+00:00", "01:59:59", "AST", 240],
+		["1951-05-27T06:00:00+00:00", "03:00:00", "ADT", 180],
+		["1951-09-02T04:59:59+00:00", "01:59:59", "ADT", 180],
+		["1951-09-02T05:00:00+00:00", "01:00:00", "AST", 240]
+	]),
+
+	"1952" : helpers.makeTestYear("Atlantic/Bermuda", [
+		["1952-05-25T05:59:59+00:00", "01:59:59", "AST", 240],
+		["1952-05-25T06:00:00+00:00", "03:00:00", "ADT", 180],
+		["1952-09-07T04:59:59+00:00", "01:59:59", "ADT", 180],
+		["1952-09-07T05:00:00+00:00", "01:00:00", "AST", 240]
+	]),
+
+	"1956" : helpers.makeTestYear("Atlantic/Bermuda", [
+		["1956-05-27T05:59:59+00:00", "01:59:59", "AST", 240],
+		["1956-05-27T06:00:00+00:00", "03:00:00", "ADT", 180],
+		["1956-10-28T04:59:59+00:00", "01:59:59", "ADT", 180],
+		["1956-10-28T05:00:00+00:00", "01:00:00", "AST", 240]
+	]),
+
 	"1974" : helpers.makeTestYear("Atlantic/Bermuda", [
 		["1974-04-28T05:59:59+00:00", "01:59:59", "AST", 240],
 		["1974-04-28T06:00:00+00:00", "03:00:00", "ADT", 180],
