@@ -232,6 +232,13 @@ exports["Atlantic/Madeira"] = {
 		["1949-10-02T03:00:00+00:00", "02:00:00", "-01", 60]
 	]),
 
+	"1950" : helpers.makeTestYear("Atlantic/Madeira", [
+		["1950-04-02T02:59:59+00:00", "01:59:59", "-01", 60],
+		["1950-04-02T03:00:00+00:00", "03:00:00", "+00", 0],
+		["1950-10-01T02:59:59+00:00", "02:59:59", "+00", 0],
+		["1950-10-01T03:00:00+00:00", "02:00:00", "-01", 60]
+	]),
+
 	"1951" : helpers.makeTestYear("Atlantic/Madeira", [
 		["1951-04-01T02:59:59+00:00", "01:59:59", "-01", 60],
 		["1951-04-01T03:00:00+00:00", "03:00:00", "+00", 0],
