@@ -3,14 +3,33 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Australia/Tasmania"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Australia/Tasmania", { offset: true, expect: "Australia/Sydney" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Australia/Tasmania", { abbr: true, expect: "Australia/Sydney" }),
+
 	"1916" : helpers.makeTestYear("Australia/Tasmania", [
 		["1916-09-30T15:59:59+00:00", "01:59:59", "AEST", -600],
 		["1916-09-30T16:00:00+00:00", "03:00:00", "AEDT", -660]
 	]),
 
 	"1917" : helpers.makeTestYear("Australia/Tasmania", [
-		["1917-03-24T14:59:59+00:00", "01:59:59", "AEDT", -660],
-		["1917-03-24T15:00:00+00:00", "01:00:00", "AEST", -600]
+		["1917-03-24T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["1917-03-24T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["1917-10-27T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["1917-10-27T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"1918" : helpers.makeTestYear("Australia/Tasmania", [
+		["1918-03-02T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["1918-03-02T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["1918-10-26T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["1918-10-26T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"1919" : helpers.makeTestYear("Australia/Tasmania", [
+		["1919-03-01T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["1919-03-01T16:00:00+00:00", "02:00:00", "AEST", -600]
 	]),
 
 	"1941" : helpers.makeTestYear("Australia/Tasmania", [
@@ -19,22 +38,22 @@ exports["Australia/Tasmania"] = {
 	]),
 
 	"1942" : helpers.makeTestYear("Australia/Tasmania", [
-		["1942-03-28T14:59:59+00:00", "01:59:59", "AEDT", -660],
-		["1942-03-28T15:00:00+00:00", "01:00:00", "AEST", -600],
+		["1942-03-28T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["1942-03-28T16:00:00+00:00", "02:00:00", "AEST", -600],
 		["1942-09-26T15:59:59+00:00", "01:59:59", "AEST", -600],
 		["1942-09-26T16:00:00+00:00", "03:00:00", "AEDT", -660]
 	]),
 
 	"1943" : helpers.makeTestYear("Australia/Tasmania", [
-		["1943-03-27T14:59:59+00:00", "01:59:59", "AEDT", -660],
-		["1943-03-27T15:00:00+00:00", "01:00:00", "AEST", -600],
+		["1943-03-27T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["1943-03-27T16:00:00+00:00", "02:00:00", "AEST", -600],
 		["1943-10-02T15:59:59+00:00", "01:59:59", "AEST", -600],
 		["1943-10-02T16:00:00+00:00", "03:00:00", "AEDT", -660]
 	]),
 
 	"1944" : helpers.makeTestYear("Australia/Tasmania", [
-		["1944-03-25T14:59:59+00:00", "01:59:59", "AEDT", -660],
-		["1944-03-25T15:00:00+00:00", "01:00:00", "AEST", -600]
+		["1944-03-25T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["1944-03-25T16:00:00+00:00", "02:00:00", "AEST", -600]
 	]),
 
 	"1967" : helpers.makeTestYear("Australia/Tasmania", [
