@@ -8,6 +8,11 @@ exports["Europe/Saratov"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Europe/Saratov", { abbr: true, expect: "Asia/Dubai" }),
 
+	"1919" : helpers.makeTestYear("Europe/Saratov", [
+		["1919-06-30T23:59:59+00:00", "03:04:17", "LMT", -11058 / 60],
+		["1919-07-01T00:00:00+00:00", "03:00:00", "+03", -180]
+	]),
+
 	"1930" : helpers.makeTestYear("Europe/Saratov", [
 		["1930-06-20T20:59:59+00:00", "23:59:59", "+03", -180],
 		["1930-06-20T21:00:00+00:00", "01:00:00", "+04", -240]
@@ -229,5 +234,10 @@ exports["Europe/Saratov"] = {
 	"2014" : helpers.makeTestYear("Europe/Saratov", [
 		["2014-10-25T21:59:59+00:00", "01:59:59", "+04", -240],
 		["2014-10-25T22:00:00+00:00", "01:00:00", "+03", -180]
+	]),
+
+	"2016" : helpers.makeTestYear("Europe/Saratov", [
+		["2016-12-03T22:59:59+00:00", "01:59:59", "+03", -180],
+		["2016-12-03T23:00:00+00:00", "03:00:00", "+04", -240]
 	])
 };
\ No newline at end of file
