@@ -239,5 +239,10 @@ exports["Europe/Volgograd"] = {
 	"2018" : helpers.makeTestYear("Europe/Volgograd", [
 		["2018-10-27T22:59:59+00:00", "01:59:59", "+03", -180],
 		["2018-10-27T23:00:00+00:00", "03:00:00", "+04", -240]
+	]),
+
+	"2020" : helpers.makeTestYear("Europe/Volgograd", [
+		["2020-12-26T21:59:59+00:00", "01:59:59", "+04", -240],
+		["2020-12-26T22:00:00+00:00", "01:00:00", "+03", -180]
 	])
 };
\ No newline at end of file
