@@ -78,6 +78,8 @@ exports["Jamaica"] = {
 
 	"1983" : helpers.makeTestYear("Jamaica", [
 		["1983-04-24T06:59:59+00:00", "01:59:59", "EST", 300],
-		["1983-04-24T07:00:00+00:00", "03:00:00", "EDT", 240]
+		["1983-04-24T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1983-10-30T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1983-10-30T06:00:00+00:00", "01:00:00", "EST", 300]
 	])
 };
\ No newline at end of file
