@@ -31,6 +31,8 @@ exports["Japan"] = {
 
 	"1951" : helpers.makeTestYear("Japan", [
 		["1951-05-05T14:59:59+00:00", "23:59:59", "JST", -540],
-		["1951-05-05T15:00:00+00:00", "01:00:00", "JDT", -600]
+		["1951-05-05T15:00:00+00:00", "01:00:00", "JDT", -600],
+		["1951-09-08T14:59:59+00:00", "00:59:59", "JDT", -600],
+		["1951-09-08T15:00:00+00:00", "00:00:00", "JST", -540]
 	])
 };
\ No newline at end of file
