@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Pacific/Chatham"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Pacific/Chatham", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Pacific/Chatham", { abbr: true }),
+
 	"1945" : helpers.makeTestYear("Pacific/Chatham", [
 		["1945-12-31T11:44:59+00:00", "23:59:59", "+1215", -735],
 		["1945-12-31T11:45:00+00:00", "00:30:00", "+1245", -765]
