@@ -8,6 +8,11 @@ exports["Pacific/Enderbury"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Pacific/Enderbury", { abbr: true, expect: "Pacific/Tongatapu" }),
 
+	"1937" : helpers.makeTestYear("Pacific/Enderbury", [
+		["1937-08-30T23:59:59+00:00", "23:59:59", "-00", 0],
+		["1937-08-31T00:00:00+00:00", "12:00:00", "-12", 720]
+	]),
+
 	"1979" : helpers.makeTestYear("Pacific/Enderbury", [
 		["1979-10-01T11:59:59+00:00", "23:59:59", "-12", 720],
 		["1979-10-01T12:00:00+00:00", "01:00:00", "-11", 660]
