@@ -235,6 +235,13 @@ exports["Portugal"] = {
 		["1949-10-02T02:00:00+00:00", "02:00:00", "WET", 0]
 	]),
 
+	"1950" : helpers.makeTestYear("Portugal", [
+		["1950-04-02T01:59:59+00:00", "01:59:59", "WET", 0],
+		["1950-04-02T02:00:00+00:00", "03:00:00", "WEST", -60],
+		["1950-10-01T01:59:59+00:00", "02:59:59", "WEST", -60],
+		["1950-10-01T02:00:00+00:00", "02:00:00", "WET", 0]
+	]),
+
 	"1951" : helpers.makeTestYear("Portugal", [
 		["1951-04-01T01:59:59+00:00", "01:59:59", "WET", 0],
 		["1951-04-01T02:00:00+00:00", "03:00:00", "WEST", -60],
