@@ -36,5 +36,10 @@ exports["Singapore"] = {
 	"1945" : helpers.makeTestYear("Singapore", [
 		["1945-09-11T14:59:59+00:00", "23:59:59", "+09", -540],
 		["1945-09-11T15:00:00+00:00", "22:30:00", "+0730", -450]
+	]),
+
+	"1981" : helpers.makeTestYear("Singapore", [
+		["1981-12-31T16:29:59+00:00", "23:59:59", "+0730", -450],
+		["1981-12-31T16:30:00+00:00", "00:30:00", "+08", -480]
 	])
 };
\ No newline at end of file
