@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["US/Alaska"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("US/Alaska", { offset: true, expect: "America/Anchorage" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("US/Alaska", { abbr: true, expect: "America/Anchorage" }),
+
 	"1942" : helpers.makeTestYear("US/Alaska", [
 		["1942-02-09T11:59:59+00:00", "01:59:59", "AST", 600],
 		["1942-02-09T12:00:00+00:00", "03:00:00", "AWT", 540]
